@@ -148,15 +148,19 @@ def _buildDictionary(componentOption, hubName):
 	data = (componentOption)
 	paramsString = db.query_selectscalar(sql, data)
 	
-	if hubzero.utilities.misc.JOOMLA_25:
-		parmsDict = json.loads(paramsString)
-	else:
-		parmsDict = {}
-		parms = paramsString.split("\n")
-		for parmline in parms:
-			if parmline: # in case of any blank lines in the params field
-				n,v = parmline.split("=", 1)
-				parmsDict[n] = v
+	if hubzero.utilities.misc.JOOMLA_25 and parmsString.startswith('{'):
+		try:
+			parmsDict = json.loads(paramsString)
+			return parmsDict
+		except:
+			pass
+
+	parmsDict = {}
+	parms = paramsString.split("\n")
+	for parmline in parms:
+		if parmline: # in case of any blank lines in the params field
+			n,v = parmline.split("=", 1)
+			parmsDict[n] = v
 
 	return parmsDict
 	
