@@ -92,6 +92,11 @@ def _del_jos_users(db, username):
 
 	return userID
 
+def _del_jos_user_usergroup_map(db, userID):
+
+	sql = "DELETE FROM `jos_user_usergroup_map` WHERE `user_id` = %s"
+	data - (userID)
+	db.query_rowcount(sql, data)
 
 def _del_jos_core_acl_aro(db, userID):
 
@@ -201,20 +206,31 @@ def _insert_jos_users(db, joomlauserid, name, username, email, password, jgidNum
 	# 18=Registered, 23=Manager, 24=Administrator, 25=Super Administrator
 	userTypeLookupDict = {18:"Registered", 23:"Manager", 24:"Administrator", 25:"Super Administrator"}
 
-	if joomlauserid == -1:
-		sql = "INSERT INTO `jos_users` (`name`, `username`, `email`, `password`, `usertype`, `block`, `sendEmail`, `gid`, `registerDate`, `lastvisitDate`, `activation`, `params`)"
-		sql += "VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s);"
-		data = (name, username, email, pw, userTypeLookupDict[int(jgidNumber)], 0, 1, jgidNumber, datetime.datetime.now(), '0000-00-00 00:00:00', '', '');
-		userID = db.query_lastrowid(sql, data)
+	if hubzero.utilities.misc.JOOMLA_25:
+		if joomlauserid == -1:
+			sql = "INSERT INTO `jos_users` (`name`, `username`, `email`, `password`, `usertype`, `block`, `sendEmail`, `registerDate`, `lastvisitDate`, `activation`, `params`)"
+			sql += "VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s);"
+			data = (name, username, email, pw, userTypeLookupDict[int(jgidNumber)], 0, 1, datetime.datetime.now(), '0000-00-00 00:00:00', '', '');
+			userID = db.query_lastrowid(sql, data)
+		else:
+			sql = "INSERT INTO `jos_users` (`id`, `name`, `username`, `email`, `password`, `usertype`, `block`, `sendEmail`, `registerDate`, `lastvisitDate`, `activation`, `params`)"
+			sql += "VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s);"
+			data = (joomlauserid, name, username, email, pw, userTypeLookupDict[int(jgidNumber)], 0, 1, datetime.datetime.now(), '0000-00-00 00:00:00', '', '');
+			userID = db.query_lastrowid(sql, data)
 	else:
-		sql = "INSERT INTO `jos_users` (`id`, `name`, `username`, `email`, `password`, `usertype`, `block`, `sendEmail`, `gid`, `registerDate`, `lastvisitDate`, `activation`, `params`)"
-		sql += "VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s);"
-		data = (joomlauserid, name, username, email, pw, userTypeLookupDict[int(jgidNumber)], 0, 1, jgidNumber , datetime.datetime.now(), '0000-00-00 00:00:00', '', '');
-		userID = db.query_lastrowid(sql, data)
+		if joomlauserid == -1:
+			sql = "INSERT INTO `jos_users` (`name`, `username`, `email`, `password`, `usertype`, `block`, `sendEmail`, `gid`, `registerDate`, `lastvisitDate`, `activation`, `params`)"
+			sql += "VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s);"
+			data = (name, username, email, pw, userTypeLookupDict[int(jgidNumber)], 0, 1, jgidNumber, datetime.datetime.now(), '0000-00-00 00:00:00', '', '');
+			userID = db.query_lastrowid(sql, data)
+		else:
+			sql = "INSERT INTO `jos_users` (`id`, `name`, `username`, `email`, `password`, `usertype`, `block`, `sendEmail`, `gid`, `registerDate`, `lastvisitDate`, `activation`, `params`)"
+			sql += "VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s);"
+			data = (joomlauserid, name, username, email, pw, userTypeLookupDict[int(jgidNumber)], 0, 1, jgidNumber , datetime.datetime.now(), '0000-00-00 00:00:00', '', '');
+			userID = db.query_lastrowid(sql, data)
 
 	return userID
 
-
 def _insert_jos_core_acl_aro(db, userID, fullname):
 	sql = "INSERT INTO `jos_core_acl_aro` (`section_value`, `value`, `order_value`, `name`, `hidden`) "
 	sql += "VALUES (%s, %s, %s, %s, %s)"
@@ -222,13 +238,16 @@ def _insert_jos_core_acl_aro(db, userID, fullname):
 	aroID = db.query_lastrowid(sql, data)
 	return aroID
 
-
 def _insert_jos_core_acl_groups_aro_map(db, jgidNumber, aroID):
 	sql = "INSERT INTO `jos_core_acl_groups_aro_map` (`group_id`, `section_value`, `aro_id`) "
 	sql += "VALUES (%s, %s, %s)"
 	data = ( jgidNumber, '', aroID)
 	db.query_rowcount(sql, data)
 
+def _insert_jos_user_usergroup_map(db, userID, groupID = 2):
+	sql = "INSERT INTO `jos_user_usergroup_map` (`user_id`, `group_id`) VALUES (%s, %s)"
+	data = (userID, groupID)
+	db.query_rowcount(sql, data)
 
 def _insert_jos_xprofiles(db, hubname, uidNumber, fname, mname, lname, username, email, password, gid, gidNumber, loginShell, homeDir):
 
@@ -436,8 +455,13 @@ def addhubuser(hubname,
 			gid = username # group name same as user
 
 		uidNumber = _insert_jos_users(db, uidNumber, fullName, username, email, pw, joomlagidNumber)
-		aroID = _insert_jos_core_acl_aro(db, uidNumber, fullName)
-		_insert_jos_core_acl_groups_aro_map(db, joomlagidNumber, aroID)
+
+		if hubzero.utilities.misc.JOOMLA_25:
+			_insert_jos_user_usergroup_map(db, uidNumber, 2)
+		else:
+	  		aroID = _insert_jos_core_acl_aro(db, uidNumber, fullName)
+			_insert_jos_core_acl_groups_aro_map(db, joomlagidNumber, aroID)
+
 		_insert_jos_xprofiles(db, hubname, uidNumber, firstName, middleName, lastName, username, email, pw, gid, gidNumber, loginShell, homeDir)
 		_insert_jos_users_password(db, uidNumber, pw)
 
@@ -486,8 +510,11 @@ def delhubuser(username, hubname = ""):
 	userID = db.query_selectscalar(sql, data)
 
 	if uidExists(username):
-		aroID = _del_jos_core_acl_aro(db, userID)
-		if aroID: _del_jos_core_acl_groups_aro_map(db, aroID)
+		if hubzero.utilities.misc.JOOMLA_25:
+			_del_jos_user_usergroup_map(db, userID)
+		else:
+			aroID = _del_jos_core_acl_aro(db, userID)
+			if aroID: _del_jos_core_acl_groups_aro_map(db, aroID)
 
 		_del_jos_xprofiles(db, userID)
 		_del_jos_users(db, username)
@@ -774,4 +801,4 @@ def _syncusers(hubname = "", purgeorphans = True, syncattributes = True, user =
 		if verbose:
 			print "syncing user '" + duser.username + "' to ldap"
 		_syncuser(duser.username, hubname, syncattributes)
-	
\ No newline at end of file
+	
